/**********************************************************************************************/
/* FBL_SetIterator.h																		  */
/*                                                                       					  */
/* Foundation Base Library ( FBL )		                                   					  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002                                       					  */
/* All Rights Reserved.                                                 					  */
/**********************************************************************************************/

#ifndef __FBL_SetIterator_h
   #define __FBL_SetIterator_h

#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/FBL.h>
#else
#	include <FBL.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
/*
	This is abstract class (Interface) 
	that define API for FBL_Set iterator.
	
	ID_TYPE -- is just ulong type.
*/

class FBL_SetIterator
{
	public://///////////////////////////////////////////////////////////////////////////////////

								FBL_SetIterator( void ) {}
virtual							~FBL_SetIterator( void ) {}

		/* Low - level methods */

								// Retuns item value, i.e. RecID (1..N).	
virtual ID_TYPE	 				operator* ( void ) const = 0;

								// Move iterator to the first/last item of the Set.
								// Returns false only if set is empty.
virtual bool					First( void ) 	= 0;
virtual bool					Last( void )	= 0;
							
								// Move iterator to the next/prev item of the Set.
								// Returns false if we are at last/first item.						
virtual bool					Next( void ) 	= 0;
virtual bool					Prev( void )	= 0;

								// Set iterator on specified item of set.
								// Returns true if such item found.
								// inIndex is 1 - based.
virtual bool					GoTo( ulong inIndex ) = 0;


	/* High level methods */

		/* 	this methods are combination of e.g. 	
		 *			iter.Next();
		 *			*iter;
		 *	so we reduce in 2 times the number of calls of virtual functions.
		 */
	
								/** Move iterator to the first/last item of the Set.
								 	Returns value of item if it found, else return 0.
									Zero can be considered as "not found". */
virtual ID_TYPE					FirstItem( void ) 	= 0;
virtual ID_TYPE					LastItem( void )	= 0;
							
								/** Move iterator to the next/prev item of the Set.
									Returns value of item if it found, else return 0.
									Zero can be considered as "not found". */
virtual ID_TYPE					NextItem( void ) 	= 0;
virtual ID_TYPE					PrevItem( void )	= 0;

};


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif
