/**********************************************************************************************/
/* VDK_Picture.h																			  */
/*                                                                       					  */
/* Valentina SDK    																		  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002															  */
/* All Rights Reserved                                                   					  */
/**********************************************************************************************/

#ifndef __VDK_Picture_h 
	#define __VDK_Picture_h
	
#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/VDK_BLOB.h>
#else
#	include <VDK_BLOB.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
#ifdef FBL_WIN
#define PicHandle  HANDLE
#endif 


/**********************************************************************************************/
class FBL_EXP VDK_Picture : public virtual VDK_BLOB
{
		friend class VDK_BaseObject;

	public://///////////////////////////////////////////////////////////////////////////////////
		
							 	// inBlockSize will be used only once - 
								// on create of blob file. It can't be changed runtime. 
FBL_EXP							VDK_Picture( 
									const char* inName, 
									ulong		inBlockSize = 10 * 1024,
									ushort		inFlags	= 0 );	


	public://///////////////////////////////////////////////////////////////////////////////////
		
FBL_EXP	ushort					GetDefQuality( void ) const;
FBL_EXP	void					SetDefQuality( ushort inValue );
		

	public://///////////////////////////////////////////////////////////////////////////////////
		
								// Read picture compressed in JPG format.
								// for MAC don't decompress it (you can draw it as it is),
								// for Windows this method decompress JPG to DIB. 
FBL_EXP	virtual PicHandle		ReadFromJPG( void );	
		
								// Write Picture (PICT for MAC, DIB for Windows)
								// compressed in JPG format with inQuality [0..100].
FBL_EXP	virtual bool 			WriteAsJPG( 
									PicHandle 	inPicture, 
									ushort 		inQuality = 0xFFFF, // use default compression for this field.
									ulong 		inHandleSize = 0 );


	public://///////////////////////////////////////////////////////////////////////////////////
		
// These 2 functions set/get into Picture field a READY picture in some format.
// for example, this can be JPG or GIF or TIFF made by PhotoShop.
//
// You need handle these 2 functions with care taking in account next:
// -- they allow you in fact keep in the same field pictures of different type.
// 		So you get pictures only by Picture_GetReady() and not by ReadFromJPG(),
//		which expect to see only JPG in the field.
//
// -- even if you store only JPGs, you still can get problems reading them by ReadFromJPG()
// 		because in current version of Valentina it do not recognise JPGs of newest format. 
//

FBL_EXP	virtual void			PutPicture( 
									ushort 		inPictType,
									const char* inPictData, 
									ulong 		inBytes );

								// Allocate and return buffer that contains data of picture,
								// outSize returns the size of picture.
								// You must destroy returned buffer using "delete [] p".
								// Buffer is NOT allocated if you specify ioPictureBuffer.
FBL_EXP	virtual char*			GetPicture( 
									ulong& 		outSize, 
									ushort&		outPictType,
									char* 		ioPictureBuffer = NULL );

	protected://////////////////////////////////////////////////////////////////////////////////

FBL_EXP virtual void			FinishCreateSelf( void );

}; 


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif  


