/**********************************************************************************************/
/* VDK_Relation.h																		 	  */
/*                                                                       					  */
/* Object Base Library ( OBL )			                                   					  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002                                        					  */
/* All Rights Reserved.                                                 					  */
/**********************************************************************************************/

#ifndef __VDK_Relation_h
   #define __VDK_Relation_h

#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/VDK_Link.h>
#	include <VSDK/FBL_String.h>
#else
#	include <VDK_Link.h>
#	include <FBL_String.h>
#endif // VSDK_FRAMEWORK_STYLE

#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
class FBL_ArraySet;
class VDK_BaseObject;


/**********************************************************************************************/
class VDK_RelationBranch	// Describe one branch of relation.
{
	public://///////////////////////////////////////////////////////////////////////////////////

	VDK_BaseObject*				pObject;		// related BaseObject

	FBL_RelType					relType;		// relation's parameter of this branch.
	FBL_DeletionControl			mDeletion;
	
	
FBL_EXP							VDK_RelationBranch( 
									VDK_BaseObject*		inBaseObject		= NULL, 
									FBL_RelType 		inRelType 			= FBL_Many,
									FBL_DeletionControl inDeletionControl	= kFBL_SET_NULL );	
};


/**********************************************************************************************/
typedef FBL_Array<VDK_RelationBranch*> BranchesArray;


/**********************************************************************************************/
class VDK_Relation : public VDK_Link
{
    public://///////////////////////////////////////////////////////////////////////////////////

		/* Construction/destruction */

FBL_EXP							VDK_Relation( void );				 
FBL_EXP							VDK_Relation( char* pName );				 
FBL_EXP virtual					~VDK_Relation( void );

		/* Initialisation: */

								// Create and add to array new branch.
FBL_EXP virtual void			CreateBranch( 
									VDK_BaseObject* 		inBaseObject,
								  	FBL_RelType 			inRelType,
									FBL_DeletionControl	inDeletionControl );
								
		/* LINK ACCESSORIES: */	
	
								// Returns name of Relation.
const 	char*					GetLinkName( void )	const { return name; }

								// Change name of Relation.
FBL_EXP	void					ChangeName( const char* pNewName );


		/* Methods to work with Relation's files */

								// Must be called after the parameters of the relation is set.
								// Init files on disk.
virtual void					Init( void ) = 0;

								// Returns true if there is no related records.			
virtual bool					IsEmpty( void ) = 0;
		
		
	 							// Delete everything: files, folder, this object.
	 							// Relation must be empty.
FBL_EXP virtual void 			DeleteRelation( void ); 
	 							

		/* BRANCHES Methods: */

								// Returns number of branches in relation.	
virtual ushort					GetBranchesCount( void ) const;
	
							 	// Returns branch from relation.	
virtual const VDK_RelationBranch* GetBranch( ushort BranchNumber ) const;
	
								// Returns BaseObject for specified branch.
virtual VDK_BaseObject*			GetObject( ushort BranchNumber ) const;

								// Returns parameters for specified branch.
FBL_EXP virtual void			GetBranchParameters( 
										ushort 					inBranchNumber, 
										FBL_RelType& 			outRelType,
										FBL_DeletionControl& 	outDeletionControl ) const;

								// Cnhange paramters of existing branch.
FBL_EXP virtual void			ChangeBranchParameters( 
										ushort 				BranchNumber,
										FBL_RelType			inNewRelType,
										FBL_DeletionControl inDeletionControl );
																
								// Returns the name of specified link in direction from
								// inBaseObjectA to inBaseObjectB.
FBL_EXP virtual	const char*		GetNameFor( 
									VDK_BaseObject* inBaseObjectA,
									VDK_BaseObject* inBaseObjectB )	const;

																
	protected://////////////////////////////////////////////////////////////////////////////////
	
								// Make all nessary work on changing RelType of Branch.
virtual void					RelTypeChanged( VDK_RelationBranch* pBranch, FBL_RelType NewType ) = 0;


	protected://////////////////////////////////////////////////////////////////////////////////
	
    	FBL_String				name;			// name of relation.
		BranchesArray			branches;		// array of Branches.
};


/**********************************************************************************************/
inline VDK_BaseObject*  VDK_Relation::GetObject( ushort BranchNumber ) const
{
	return GetBranch( BranchNumber )->pObject;
}

/**********************************************************************************************/
inline const VDK_RelationBranch* VDK_Relation::GetBranch( ushort BranchNumber ) const
{
	return branches.GetItemAt( BranchNumber );

} 


/**********************************************************************************************/
inline ushort VDK_Relation::GetBranchesCount( void ) const
{
	return (ushort) branches.GetCount();
	
} /* VDK_Relation::GetBranchesCount */


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif // __VDK_Relation_h
