/**********************************************************************************************/
/* VDK_String.h																				  */
/*                                                                       					  */
/* Valentina SDK    																		  */
/*                                                                       					  */
/* Copyright Paradigma, 1993-2002															  */
/* All Rights Reserved                                                   					  */
/**********************************************************************************************/

#ifndef __VDK_String_h 
	#define __VDK_String_h
	
#if VSDK_FRAMEWORK_STYLE
#	include <VSDK/VDK_Field.h>
#	include <VSDK/FBL_StringUtilities.h>
#else
#	include <VDK_Field.h>
#	include <FBL_StringUtilities.h>
#endif // VSDK_FRAMEWORK_STYLE


#if defined(__MWERKS__)
	#pragma options align=power
#endif


/**********************************************************************************************/
// Valentina store strings in the indexes as varaible length pascal strings always.

// VDK_String 	stores strings in the table as fixed length strings
// VDK_VarChar 	stores strings in the tables as variable length strings.
// VDK_Text 	stores strings as BLOB objects (also variable length, based on segments).
// VDK_Byte 	is most effective to store strings with length 1 character.


/**********************************************************************************************/
class FBL_EXP VDK_String : public virtual VDK_Field
{
		friend class VDK_BaseObject;

	public://///////////////////////////////////////////////////////////////////////////////////
		
FBL_EXP							VDK_String( 
									const char* inName, 
									ushort		inMaxLen	= 20, 
									const char* inLanguage	= NULL, // "ASCII" language
									ushort		inFlags		= 0 );
									
		/* Value methods */
		
FBL_EXP virtual void           	operator= ( const char* inValue );
FBL_EXP virtual             	operator const char*( void ) const;

FBL_EXP	ushort					GetMaxLen( void ) const;			

								// Set new length for this field.
								// This function modify size of record and 
								// Table must be rebuild if it is not empty.
FBL_EXP virtual void			SetMaxLen( ushort inMaxLen );
			
		
		/* Search methods */
		
FBL_EXP	FBL_BitSet*				Find( const char* inLeftValue , bool inLeftInclude, 
									  const char* inRightValue, bool inRightInclude );
		
FBL_EXP	FBL_BitSet* 			Find( const char* inKey = NULL );
		
FBL_EXP	FBL_BitSet*				SearchLike( const char* inValue, bool inMatchCase = true );
FBL_EXP	FBL_BitSet*				SearchRegEx( const char* inValue, bool inMatchCase = true );


		// Methods for international support: 

FBL_EXP	FBL_Language*			GetLanguage( void ) const;
					
								// Set Language, e.g. "ASCII", "German", "Italian" 
FBL_EXP	void					SetLanguage( 
									const char*	inLanguage, 
									bool		inSaveOnDwisk = true );

FBL_EXP	void					SetCompareFunction( 
                                    FBL_CompareStringPtr inCompare, 
                                    bool inPreserveIndex = false );

								// This methods can store in String field data with 0 inside
FBL_EXP	ushort					ReadRawData( void* inDataPtr, ushort inBufferSize );
FBL_EXP	void					WriteRawData( const void* inDataPtr, ushort inBufferSize );


	protected://////////////////////////////////////////////////////////////////////////////////
		 
FBL_EXP virtual void			FinishCreateSelf( void );


	protected://////////////////////////////////////////////////////////////////////////////////
		 
		ushort					mMaxLen;	
	 	FBL_Language*			mLanguage;

}; 


/**********************************************************************************************/
#if defined(__MWERKS__)
	#pragma options align=reset
#endif

#endif  


